@@ -1,4 +1,4 @@
-/* $Id: subnetcalc.cc 593 2010-06-29 20:48:45Z dreibh $
+/* $Id: subnetcalc.cc 1023 2011-05-03 17:07:41Z dreibh $
  *
  * IPv4/IPv6 Subnet Calculator
  * Copyright (C) 2002-2010 by Thomas Dreibholz
@@ -211,9 +211,10 @@ void printAddressBinary(std::ostream&         os,
       os << std::endl;
    }
    else {
-      int p = 0;
+      int      p           = 0;
+      in6_addr ipv6Address = getIPv6Address(address);
       for(int j = 0;j < 8;j++) {
-         uint16_t a = ntohs(((const uint16_t*)&getIPv6Address(address).s6_addr)[j]);
+         uint16_t a = ntohs(((const uint16_t*)&ipv6Address.s6_addr)[j]);
          char str[16];
          snprintf((char*)&str, sizeof(str), "%04x", a);
          os << indent << str << " = ";
